.. currentmodule:: sardana.sardanaattribute

:mod:`~sardana.pool.sardanaattribute`
=====================================

.. automodule:: sardana.sardanaattribute

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`SardanaAttribute`
    * :class:`SardanaSoftwareAttribute`
    * :class:`ScalarNumberAttribute`
    * :class:`SardanaAttributeConfiguration`

SardanaAttribute
----------------

.. inheritance-diagram:: SardanaAttribute
    :parts: 1
    
.. autoclass:: SardanaAttribute
    :inherited-members:
    :members:
    :undoc-members:

SardanaSoftwareAttribute
------------------------

.. inheritance-diagram:: SardanaSoftwareAttribute
    :parts: 1
    
.. autoclass:: SardanaSoftwareAttribute
    :inherited-members:
    :members:
    :undoc-members:

ScalarNumberAttribute
---------------------

.. inheritance-diagram:: ScalarNumberAttribute
    :parts: 1
    
.. autoclass:: ScalarNumberAttribute
    :inherited-members:
    :members:
    :undoc-members:

SardanaAttributeConfiguration
-----------------------------

.. inheritance-diagram:: SardanaAttributeConfiguration
    :parts: 1
    
.. autoclass:: SardanaAttributeConfiguration
    :inherited-members:
    :members:
    :undoc-members:
